% Load the strain data. This data contains the minimum, average and maximum
% strain, as well as the cell size for each cell.
clear all; close all
[data, header] = readcsv('strainData_new.csv');

% Define the output of interest and find corresponding row
ooi = 'strain_maximum';
column_data = find(strcmp(header, ooi));
column_area = find(strcmp(header, 'Area'));

% We make a histogram according weighed by surface area to prevent that
% large cells are weighed the same as small cells, although they represent
% a much larger surface area

nbin=45;
[percentiles, percentilesData] =...
    computePercentiles(data(:,column_data), data(:,column_area));
[histogram] = computeHistogram(data(:,column_data), data(:,column_area),1,1.02,nbin);

% Plot the cummulative densitiy function and a histogram (pdf scaling: area
% under curve = 1)

%% PERCENTILE PLOTTING

clr=lines(1);
figure; set(gcf,'position',[100,100,400,300]); set(gca,'color','none'); set(gcf,'PaperPositionMode','auto'); hold on
set(gca,'fontsize',14)
plot(percentilesData, (percentiles-1)*100,'k')

% Find the percentile of the value used in the study by Eline
elineVal = 0.023; %2.3 % according to my notes
[~, min_index] = min(abs(percentiles-1 - elineVal));
percentileEline = percentilesData(min_index);
fprintf('The value used in the study by Eline corresponds to the %.1f percentile\n', percentileEline);

plot([0 100],[2.3 2.3],'--','color',clr(1,:))
plot([percentileEline percentileEline],[-5 15],'--','color',clr(1,:))

xlabel('percentile')
ylabel('epsilon (%)')
ylim([-2 4])

%% HISTOGRAM PLOTTING

figure; set(gcf,'position',[100,100,400,300]); set(gca,'color','none'); set(gcf,'PaperPositionMode','auto'); hold on
set(gca,'fontsize',14)
bar((histogram(1,:)-1.)*100, histogram(2,:),'barwidth',1,'facecolor',[0.8 0.8 0.8])
% xlim([0 2])
xlabel('epsilon (%)')
ylabel('frequency (-)')
title([num2str(sum(100*histogram(2,:)),4),' %'])