% Load the strain data. This data contains the minimum, average and maximum
% strain, as well as the cell size for each cell.
clear all; close all
[data, header] = readcsv('wssData_new.csv');

% Define the output of interest and find corresponding row
ooi = 'tawss';
column_data = find(strcmp(header, ooi));
column_area = find(strcmp(header, 'Area'));

%WSS has a scaling of 1/1050 due to CFD setup
data(:, column_data) = data(:, column_data) * 1050;

% We make a histogram according weighed by surface area to prevent that
% large cells are weighed the same as small cells, although they represent
% a much larger surface area
nbin = 45; 

[percentiles, percentilesData] =...
    computePercentiles(data(:,column_data), data(:,column_area));
[histogram] = computeHistogram(data(:,column_data), data(:,column_area),0,20,nbin);

% Plot the cummulative densitiy function and a histogram (pdf scaling: area
% under curve = 1)

%% PERCENTILE PLOTTING

clr=lines(2);

figure; set(gcf,'position',[100,100,400,300]); set(gca,'color','none'); set(gcf,'PaperPositionMode','auto'); hold on
set(gca,'fontsize',14)
plot(percentilesData, (percentiles),'k')

% Find the percentile of the value used in the study by Eline
elineVal = 3.2; %3.2Pa according to my notes
[~, min_index] = min(abs(percentiles - elineVal));
percentileEline = percentilesData(min_index);
fprintf('The value used in the study by Eline corresponds to the %.1f percentile\n', percentileEline);


plot([0 100],[elineVal elineVal],'--','color',clr(1,:))
plot([percentileEline percentileEline],[-5 15],'--','color',clr(1,:))


elineVal = 0.5; %3.2Pa according to my notes
[~, min_index] = min(abs(percentiles - elineVal));
percentileEline = percentilesData(min_index);
fprintf('The value used in the study by Eline corresponds to the %.1f percentile\n', percentileEline);

plot([0 100],[elineVal elineVal],'--','color',clr(2,:))
plot([percentileEline percentileEline],[-5 15],'--','color',clr(2,:))

xlabel('percentile')
ylabel('TAWSS (Pa)')
xlim([0 100])
ylim([0 10])

%% HISTOGRAM PLOTTING

figure; set(gcf,'position',[100,100,400,300]); set(gca,'color','none'); set(gcf,'PaperPositionMode','auto'); hold on
set(gca,'fontsize',14)
bar(histogram(1,:), histogram(2,:),'barwidth',1,'facecolor',[0.8 0.8 0.8])
xlim([0 20])
xlabel('TAWSS (Pa)')
ylabel('frequency (-)')
title([num2str(sum(100*histogram(2,:)),4),' %'])
